@@ -16,9 +16,10 @@ class APITest(unittest.TestCase):
     def testRender(self):
         self.assertTrue( Tempest.__dict__.has_key('render') )
     
-    def testVersions(self):
+    def testStaticMethods(self):
         self.assertTrue( Tempest.__dict__.has_key('version') )
         self.assertTrue( Tempest.__dict__.has_key('api_version') )
+        self.assertTrue( Tempest.__dict__.has_key('has_image_lib') )
     
     def testGettersAndSetters(self):
         props = [
